@@ -4,7 +4,7 @@ from typing import List, Tuple, Union
 import numpy as np
 import numpy.typing as npt
 from earcut.earcut import earcut, normal
-from metacity.models import FacetModel
+from metacity.models.model import FacetModel
 
 
 def generate_hole_indices(surface: List[List[int]]) -> Union[List[int], None]:
