@@ -5,7 +5,7 @@ from typing import Dict
 import numpy as np
 from metacity.geometry.surfaces import process_model
 from metacity.helpers.iter import ensure_iterable
-from metacity.models import MetacityObject
+from metacity.models.object import MetacityObject
 from metacity.project import MetacityLayer
 from tqdm import tqdm
 
