@@ -2,7 +2,7 @@ from metacity.helpers.iter import ensure_list_like
 from typing import Iterable, List, TextIO, Union
 
 import numpy as np
-from metacity.models import MetacityObject
+from metacity.models.object import MetacityObject
 
 
 def buffers_to_stl(flat_vertices, flat_normals, model_name, file, shift = np.array([0, 0, 0])):  
